@@ -1,12 +1,16 @@
-from typing import List, Tuple
+from typing import List, Tuple, Union
 import json
 import re
 import httpx
 import os
+import sys
+import traceback
 from nonebot import get_bot
 from nonebot.log import logger
 from os.path import abspath, dirname
-
+from nonebot.adapters.onebot.v11.event import GroupMessageEvent, PrivateMessageEvent
+from .db import bili_database
+from .exception import *
 PackagePath =  dirname(abspath(__file__))
 
 __PLUGIN_NAME = "[B站整合~基础]"
@@ -90,10 +94,13 @@ async def parseB23Url(url: str) -> Tuple[bool, int, str]:
     """ 
     API = 'https://duanwangzhihuanyuan.bmcx.com/web_system/bmcx_com_www/system/file/duanwangzhihuanyuan/get/?ajaxtimestamp=1646565831920'
     payload = {'turl': url}
-    async with httpx.AsyncClient() as client:
-
-        res = await client.post(url=API, data=payload)
-    assert res.status_code == 200, f'转换短链接时发生异常，status_code = {res.status_code}'
+    try:
+        async with httpx.AsyncClient() as client:
+            res = await client.post(url=API, data=payload)
+    except Exception as e:
+        raise BiliConnectionError(f"转换短连接{url}时发生网络错误:{e.args[0]}")
+    if res.status_code != 200:
+        raise BiliConnectionError(f"转换短连接{url}时连接出错:状态码={res.status_code}")
 
     if re.search("live.bilibili.com", res.text):
         roomNumber = re.search("live.bilibili.com/\d+", res.text)
@@ -108,8 +115,8 @@ async def parseB23Url(url: str) -> Tuple[bool, int, str]:
     elif re.search("www.bilibili.com/bangumi/play/ep", res.text):
         epid = re.search("www.bilibili.com/bangumi/play/ep\d+", res.text)
         epid = epid.group()
-        logger.debug(f'{__PLUGIN_NAME}短链接{url}是番剧播放页面,epid为{epid[32:]}')
-        return (True, 3, epid[32:])
+        logger.debug(f'{__PLUGIN_NAME}短链接{url}是番剧播放页面,epid为{"ep" + epid[32:]}')
+        return (True, 3, "ep" + epid[32:])
     
     return (False, 0, '')
 
@@ -125,13 +132,8 @@ def GetAllUser() -> List[str]:
     返回所有用户qq号组成的列表
     -------
     """
-    
-    users = os.listdir(f'{PackagePath}/file/user')
-    result = []
-    for user in users:
-        userID = user.split('.')[0]
-        result.append(userID)
-    return result
+    qq_users = bili_database.query_all(3)
+    return [i[0] for i in qq_users]
 
 def GetAllGroup() -> List[str]:
     """
@@ -145,13 +147,9 @@ def GetAllGroup() -> List[str]:
     返回所有群号组成的列表
     -------
     """
-    
-    users = os.listdir(f'{PackagePath}/file/group')
-    result = []
-    for user in users:
-        userID = user.split('.')[0]
-        result.append(userID)
-    return result
+
+    qq_groups = bili_database.query_all(4)
+    return [i[0] for i in qq_groups]
 
 async def SendMsgToUsers(msg: str, users: List[str]):
     """
@@ -183,6 +181,31 @@ async def SendMsgToGroups(msg: str, groups: List[str]):
     for group in groups:
         await bot.send_msg(message=msg, group_id = group)
 
+async def create_user(event: Union[PrivateMessageEvent, GroupMessageEvent]) -> None:
+    '''接受消息后,创建用户
+
+    Args:
+        event (Union[PrivateMessageEvent, GroupMessageEvent]): 消息事件
+    '''
+
+    user_type = 0 if isinstance(event, PrivateMessageEvent) else 1
+    user_id = event.sender.user_id if user_type == 0 else event.group_id
+    try:
+        user_info = bili_database.query_info(user_type, str(user_id))
+        if not user_info:
+            logger.info(f'{__PLUGIN_NAME}用户{user_id}不存在于数据库,即将创建')
+            name = event.sender.nickname
+            if user_type == 1:
+                bot = get_bot()
+                group_info = await bot.get_group_info(group_id=user_id)
+                name = group_info["group_name"]
+            bili_database.insert_info(user_type, user_id, name)
+    except Exception as _:
+            ex_type, ex_val, _ = sys.exc_info()
+            exception_msg = '【错误报告】\n创建用户时发生错误\n错误类型: {}\n错误值: {}\n'.format(ex_type, ex_val)
+            logger.error(f"{__PLUGIN_NAME}\n" + exception_msg + traceback.format_exc())
+
+
 def CheckDir():
     """
     @description  :
